"""
netdisco.util.database
~~~~~~~~~~~~~~~~~~~~~~

Access to Netdisco database using SQLAlchemy and psycopg (v3).
"""

import os
from sqlalchemy import create_engine, URL

db_connect_url = URL.create(
    drivername='postgresql+psycopg',
    username=os.environ.get('PGUSER', None),
    password=os.environ.get('PGPASSWORD', None),
    host=os.environ.get('PGHOST', None),
    port=os.environ.get('PORT', None),
    database=os.environ.get('PGDATABASE', None),
)

engine = create_engine(
    db_connect_url, echo=False if os.environ.get('DBIC_TRACE', '0') == '0' else True
)



"""
netdisco.util.log
~~~~~~~~~~~~~~~~~

This module provides a utility function debug() to emit log lines at level
DEBUG (if Netdisco configuration enables that, with "log: debug"). Log
messages are prefixed with the current process ID.
"""

import logging
from os import getpid, environ
from netdisco.util.config import setting

logging.basicConfig(
    format=('[' + str(getpid()) + '] %(message)s'),
    level=getattr(logging, environ.get('ND2_LOG_LEVEL', setting('log')).upper()),
)
log = logging.getLogger(__name__)

if setting('paramiko_logging') is not True:
    logging.getLogger('paramiko').setLevel(logging.CRITICAL + 1)
if setting('netmiko_logging') is not True:
    logging.getLogger('netmiko').setLevel(logging.CRITICAL + 1)


def debug(message):
    log.debug(str(message))
